###########################################################################
#
# win32.mak -- Windows Makefile for runtime-src\src\colservr
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2010  The New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################


GSDL_DIR = $(GSDLHOME)


# Libraries compiled
LIBRARIES = gsdlcolservr.lib

# Library: gsdlcolservr.lib
# Do NOT add the "recpt" directory here: the colserver should be independent of the receptionist!
LIBCOLSERVR_CPPFLAGS = \
	-I"$(GSDL_DIR)\common-src\src\lib"

LIBCOLSERVR_OBJECTS = \
	browsefilter.obj \
	collectserver.obj \
	collectset.obj \
	colservrconfig.obj \
	comtypes.obj \
	expat_document.obj \
	expat_resultset.obj \
	filter.obj \
	lucenequeryfilter.obj \
	lucenesearch.obj \
	lucenesource.obj \
	maptools.obj \
	phrasesearch.obj \
	querycache.obj \
	queryfilter.obj \
	queryinfo.obj \
	search.obj \
	source.obj \
	sqlbrowsefilter.obj


# Option: Lucene support
!IF $(ENABLE_LUCENE)
LIBCOLSERVR_CPPFLAGS = -DENABLE_LUCENE $(LIBCOLSERVR_CPPFLAGS) -I"$(GSDL_DIR)\common-src\packages\windows\expat\expat"
!ENDIF

# Option: SQLite support
!IF $(USE_SQLITE)
LIBCOLSERVR_CPPFLAGS = -DUSE_SQLITE $(LIBCOLSERVR_CPPFLAGS) -I"$(GSDL_DIR)\common-src\packages\sqlite\include"
!ENDIF


COMPILE = cl -nologo -c -EHsc -D__WIN32__ -DXML_STATIC -D_CRT_SECURE_NO_DEPRECATE $(LIBCOLSERVR_CPPFLAGS)
LINK = cl -nologo -Fe"$@"

.SUFFIXES:
.SUFFIXES: .cpp .obj

.cpp.obj:
	$(COMPILE) $<


gsdlcolservr.lib: $(LIBCOLSERVR_OBJECTS)
	if EXIST gsdlcolservr.lib del gsdlcolservr.lib
	lib -nologo /out:gsdlcolservr.lib $(LIBCOLSERVR_OBJECTS)

all: $(LIBRARIES)

install: $(LIBRARIES)

distclean:
	del *.obj $(LIBRARIES) win32.mak

clean:
	del *.obj $(LIBRARIES)
